@@ -1,6 +1,6 @@
 /* BlinkenLib
- * version 0.1.3 date 2008-09-29
- * Copyright (C) 2004-2008: Stefan Schuermans <1stein@schuermans.info>
+ * version 0.1.4 date 2009-11-21
+ * Copyright (C) 2004-2009: Stefan Schuermans <stefan@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a blinkenarea.org project
  */
@@ -233,7 +233,7 @@ public class BlinkenFrame
           for( c = 0; c < this.channels; c++ )
             new_data[emptyY + y][destI + c] = (byte)((((int)data[skipY + y][srcI + c] & 0xFF) * maxval + this.maxval / 2) / this.maxval);
 	  for( ; c < channels; c++ )
-	    new_data[emptyY + y][destI + c] = new_data[emptyY + y][srcI + this.channels - 1];
+	    new_data[emptyY + y][destI + c] = new_data[emptyY + y][destI + this.channels - 1];
 	}
 	else //remove channels: merge leftover channels with last kept channel
 	{
